@@ -14,14 +14,16 @@ from laceworkjupyter.helper import LaceworkJupyterClient as LaceworkJupyterHelpe
 import snowflake.connector
 
 # Import forensic tools designed for notebooks.
-from picatrix import notebook_init
+# TODO (kiddi): Re-enable once TS API has been fiex, see #2388 on Timesketch.
+#from picatrix import notebook_init
 import ds4n6_lib as ds
 
 # Add in the accessors to pandas.
 from laceworkjupyter import accessors
 
 # Enable the Picatrix helpers.
-notebook_init.init()
+# TODO (kiddi): Re-enable once TS is fixed, see above.
+#notebook_init.init()
 
 # Enable the LW object.
 lw = laceworkjupyter.LaceworkHelper()
