@@ -5,7 +5,7 @@ Test suite for the community-developed Python SDK for interacting with Lacework
 
 import pytest
 
-from laceworksdk.api.run_reports import RunReportsAPI
+from laceworksdk.api.v1.run_reports import RunReportsAPI
 
 
 # Tests
